@@ -23,7 +23,7 @@
 
 namespace // anonymous
 {
-typedef std::map<xmlpp::Node*, xmlElementType> NodeMap;
+using NodeMap = std::map<xmlpp::Node*, xmlElementType>;
 
 // Find all C++ wrappers of 'node' and its descendants.
 // Compare xmlpp::Node::free_wrappers().
@@ -31,7 +31,7 @@ void find_wrappers(xmlNode* node, NodeMap& node_map)
 {
   if (!node)
     return;
-    
+
   //If an entity declaration contains an entity reference, there can be cyclic
   //references between entity declarations and entity references. (It's not
   //a tree.) We must avoid an infinite recursion.
@@ -69,9 +69,9 @@ void find_wrappers(xmlNode* node, NodeMap& node_map)
     return;
 
   //Walk the attributes list.
-  //Note that some "derived" structs have a different layout, so 
+  //Note that some "derived" structs have a different layout, so
   //_xmlNode::properties would be a nonsense value, leading to crashes
-  //(and shown as valgrind warnings), so we return above, to avoid 
+  //(and shown as valgrind warnings), so we return above, to avoid
   //checking it here.
   for (auto attr = node->properties; attr; attr = attr->next)
     find_wrappers(reinterpret_cast<xmlNode*>(attr), node_map);
@@ -83,7 +83,7 @@ void remove_found_wrappers(xmlNode* node, NodeMap& node_map)
 {
   if (!node)
     return;
-    
+
   if (node->type != XML_ENTITY_REF_NODE)
   {
     // Walk the children list.
@@ -152,7 +152,7 @@ Document::Init::Init()
   xmlInitParser(); //Not always necessary, but necessary for thread safety.
 }
 
-Document::Init::~Init()
+Document::Init::~Init() noexcept
 {
   //We don't call this because it breaks libxml generally and should only be
   //called at the very end of a process, such as at the end of a main().
@@ -179,6 +179,9 @@ Document::Document(const Glib::ustring& version)
 Document::Document(xmlDoc* doc)
   : impl_(doc)
 {
+  if (!impl_)
+    throw internal_error("xmlDoc pointer cannot be nullptr");
+
   impl_->_private = this;
 }
 
@@ -293,7 +296,7 @@ Element* Document::create_root_node_by_import(const Node* node,
 CommentNode* Document::add_comment(const Glib::ustring& content)
 {
   auto child = xmlNewComment((const xmlChar*)content.c_str());
- 
+
   // Use the result, because child can be freed when merging text nodes:
   auto node = xmlAddChild((xmlNode*)impl_, child);
   if (!node)
@@ -404,7 +407,7 @@ void Document::do_write_to_stream(std::ostream& output, const Glib::ustring& enc
   xmlResetLastError();
   const int result = xmlSaveFormatFileTo(buffer.cobj(), impl_,
     get_encoding_or_utf8(encoding), format ? 1 : 0);
-  
+
   if(result == -1)
   {
     throw exception("do_write_to_stream() failed.\n" + format_xml_error());
@@ -415,10 +418,11 @@ void Document::set_entity_declaration(const Glib::ustring& name, XmlEntityType t
                               const Glib::ustring& publicId, const Glib::ustring& systemId,
                               const Glib::ustring& content)
 {
-  auto entity = xmlAddDocEntity( impl_, (const xmlChar*) name.c_str(), type,
+  auto entity = xmlAddDocEntity(impl_, (const xmlChar*)name.c_str(),
+    static_cast<int>(type),
     publicId.empty() ? nullptr : (const xmlChar*)publicId.c_str(),
     systemId.empty() ? nullptr : (const xmlChar*)systemId.c_str(),
-    (const xmlChar*) content.c_str() );
+    (const xmlChar*)content.c_str());
   if (!entity)
     throw internal_error("Could not add entity declaration " + name);
 }
@@ -469,12 +473,12 @@ _xmlEntity* Document::get_entity(const Glib::ustring& name)
   return xmlGetDocEntity(impl_, (const xmlChar*) name.c_str());
 }
 
-_xmlDoc* Document::cobj()
+_xmlDoc* Document::cobj() noexcept
 {
   return impl_;
 }
 
-const _xmlDoc* Document::cobj() const
+const _xmlDoc* Document::cobj() const noexcept
 {
   return impl_;
 }
